Learn R Programming

phantSEM (version 1.0.0.0)

SA_lookup: Lookup Table for Sensitivity Analysis

Description

SA_lookup() is used to look up the sensitivity analysis results for a two-wave mediation model when provided with the cross-sectional correlations.

Usage

SA_lookup(CorXM, CorXY, CorMY)

Value

Results of a sensitivity analysis with varying cross-lagged and autoregressive correlations.

Arguments

CorXM

The observed correlation between predictor X and mediator M.

CorXY

The observed correlation between predictor X and outcome Y.

CorMY

The observed correlation between mediator M and outcome Y.

Examples

Run this code
# specify correlations
xm <- .2
xy <- .3
my <- .4

output <- SA_lookup(
  CorXM = xm,
  CorXY = xy,
  CorMY = my
)

Run the code above in your browser using DataLab