powered by
SA_lookup() is used to look up the sensitivity analysis results for a two-wave mediation model when provided with the cross-sectional correlations.
SA_lookup()
SA_lookup(CorXM, CorXY, CorMY)
Results of a sensitivity analysis with varying cross-lagged and autoregressive correlations.
The observed correlation between predictor X and mediator M.
The observed correlation between predictor X and outcome Y.
The observed correlation between mediator M and outcome Y.
# specify correlations xm <- .2 xy <- .3 my <- .4 output <- SA_lookup( CorXM = xm, CorXY = xy, CorMY = my )
Run the code above in your browser using DataLab